(function () {
  // get current domain name.
  var domain = window.location.hostname.replace(/(http(s)?:\/\/)?(www\.)?/, '');

  /**
   * Make external links to be opened on new tab.
   *
   * @return {Void}
   */
  function force_external_links_on_new_tab() {
    // do process in other thread to avoid impact performance.
    new Promise(function (done, fail) {
      // set internal link regular expression.
      var internal_link_regexp = new RegExp('^(http(s)?:\/\/)?(www\.)?' + domain + '?/');

      // get all links and set that external ones must be opened on new tab.
      document.querySelectorAll('a').forEach(function (link) {
        // link points to nothing.
        if (!link.href || ('#' === link.href[0]) || ('javascript:void(0)' === link.href) || (':void(0)' === link.href)) {
          return;
        }

        // it's an internal link.
        if (internal_link_regexp.test(link.href)) {
          return;
        }

        // it's an external link and must be opened in other tab.
        link.target = '_blank';
      });

      done();
    });
  }

  /**
   * Perform required actions after page has been fully loaded.
   *
   * @return {Void}
   */
  function on_document_ready() {
    // alter external links to be opened in new tab.
    force_external_links_on_new_tab();
  }

  // wait for page full load.
  document.addEventListener("DOMContentLoaded", on_document_ready);
})();